@@ -9,6 +9,8 @@
  #
  #  Copyright   : David Tschumperle
  #                ( http://www.greyc.ensicaen.fr/~dtschump/ )
+ #                Antonio Albiol Colomer
+ #                ( http://personales.upv.es/~aalbiol/index-english.html )
  #
  #  License     : CeCILL v2.0
  #                ( http://www.cecill.info/licences/Licence_CeCILL_V2-en.html )
@@ -46,6 +48,28 @@ using namespace cimg_library;
 #undef min
 #undef max
 
+// Compute distance from a point to a segment.
+//---------------------------------------------
+float dist_segment(const float x, const float y, const float x1, const float y1, const float x2, const float y2) {
+  const float
+    dx = x2 - x1,
+    dy = y2 - y1,
+    long_segment = (float)std::sqrt(dx*dx + dy*dy);
+  if (long_segment==0) { const float ddx = x - x1, ddy = y - y1; return (float)std::sqrt(ddx*ddx + ddy*ddy); }
+  const float
+    unitx = dx/long_segment,
+    unity = dy/long_segment,
+    vx = x - x1,
+    vy = y - y1,
+    long_proy = vx*unitx + vy*unity,
+    proyx = x1 + long_proy*unitx,
+    proyy = y1 + long_proy*unity;
+  if (long_proy>long_segment) { const float ddx = x - x2, ddy = y - y2; return std::sqrt(ddx*ddx+ddy*ddy); }
+  else if (long_proy<0) { const float ddx = x - x1, ddy = y - y1; return std::sqrt(ddx*ddx+ddy*ddy); }
+  const float ddx = x - proyx, ddy = y - proyy;
+  return std::sqrt(ddx*ddx+ddy*ddy);
+}
+
 // Main procedure
 //---------------
 int main(int argc, char **argv) {
@@ -133,12 +157,10 @@ int main(int argc, char **argv) {
           pnext = closed?(p+1)%points.size():(p+1<(int)points.size()?p+1:p);
         const float
           xp = points(p,0),
-          yp = points(p,1),
-          xm = 0.5f*(xp + points(pnext,0)),
-          ym = 0.5f*(yp + points(pnext,1));
+          yp = points(p,1);
         const float
           d_pt  = (xp-x)*(xp-x) + (yp-y)*(yp-y),
-          d_seg = (xm-x)*(xm-x) + (ym-y)*(ym-y);
+          d_seg = dist_segment(x,y,xp,yp,points(pnext,0),points(pnext,1));
         if (d_pt<dmin_pt)   { dmin_pt = d_pt; p_pt = p; }
         if (d_seg<dmin_seg) { dmin_seg = d_seg; p_seg = p; }
       }
