@@ -119,8 +119,8 @@ int main(int argc, char **argv) {
       } else cimg_forXY(board,x,y) if (board(x,y)) img.draw_image(x<<5,y<<5,balls[board(x,y)],mask);
       if (title) {
         CImg<unsigned char> text1, text2;
-        text1.draw_text(0,0,"- Jawbreaker -",white,0,1,48);
-        text2.draw_text(0,0,"Press button to start",yellow,0,1,24);
+        text1.draw_text(0,0,"- Jawbreaker -",white,0,1,48).resize(-100,-100,1,3);
+        text2.draw_text(0,0,"Press button to start",yellow,0,1,24).resize(-100,-100,1,3);
         (img/=2).draw_image((Wi-text1.width())/2,
                             (Hi-text1.height())/2,
                             text1,text1.get_dilate(7),1,255).
@@ -132,7 +132,7 @@ int main(int argc, char **argv) {
                                     (int)(Wi*(0.5f+i*i/200.0f)),(int)(Hi*(0.5f+i*i*i*i/20000.0f)))).wait(20);
       }
     }
-    if ((opac-=0.02f)>0) disp.display((+img).draw_text(disp.mouse_x()-8,disp.mouse_y()-54+(int)(30*opac),"+%u",
+    if ((opac-=0.06f)>0) disp.display((+img).draw_text(disp.mouse_x()-8,disp.mouse_y()-80+(int)(60*opac),"+%u",
                                                        white,0,(float)std::sqrt(opac),32,shape_score)).wait(20);
     else { if (redraw) { disp.display(img); redraw = false; } else disp.wait(); }
 
